
# Symbulate

*Symbulate* is a Python package which provides a user friendly
 framework for specifying and conducting simulations from probability models.

# Installation Instructions

It is recommended that you first install the
[Anaconda distribution](https://www.anaconda.com/download/), which
is a Python environment with many scientific packages installed
(including all of the packages that Symbulate is built on).

The fastest way to get up and running with Symbulate is to run the
command `pip install symbulate` at the command line.


# Documentation

Please see the [documentation](https://dlsun.github.io/symbulate/index.html) for examples of how to use Symbulate.
